@@ -18,7 +18,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 $(function () {
-    $("#optQueryLogsAppName").change(function () {
+    $("#optQueryLogsAppName").on("change", function () {
         if (appsList == null)
             return;
 
@@ -40,7 +40,7 @@ $(function () {
         $("#txtAddEditRecordDataData").val("");
     });
 
-    $("#optQueryLogsEntriesPerPage").change(function () {
+    $("#optQueryLogsEntriesPerPage").on("change", function () {
         localStorage.setItem("optQueryLogsEntriesPerPage", $("#optQueryLogsEntriesPerPage").val());
     });
 
@@ -56,11 +56,28 @@ function refreshLogsTab() {
         refreshQueryLogsTab();
 }
 
-function refreshLogFilesList() {
+function logsClusterNodeChanged() {
+    if ($("#logsTabListLogViewer").hasClass("active")) {
+        if ($("#divLogViewer").is(":visible"))
+            refreshLogFilesList($("#txtLogViewerTitle").text());
+        else
+            refreshLogFilesList();
+    }
+    else if ($("#logsTabListQueryLogs").hasClass("active")) {
+        refreshQueryLogsTab();
+
+        if ($("#divQueryLogsTable").is(":visible"))
+            queryLogs();
+    }
+}
+
+function refreshLogFilesList(selectedFileName) {
     var lstLogFiles = $("#lstLogFiles");
 
+    var node = $("#optLogsClusterNode").val();
+
     HTTPRequest({
-        url: "api/logs/list?token=" + sessionData.token,
+        url: "api/logs/list?token=" + sessionData.token + "&node=" + encodeURIComponent(node),
         success: function (responseJSON) {
             var logFiles = responseJSON.response.logFiles;
 
@@ -80,6 +97,18 @@ function refreshLogFilesList() {
             }
 
             lstLogFiles.html(list);
+
+            if (selectedFileName != null) {
+                for (var i = 0; i < logFiles.length; i++) {
+                    if (logFiles[i].fileName == selectedFileName) {
+                        viewLog(selectedFileName);
+                        return;
+                    }
+                }
+
+                //selected file not found
+                $("#divLogViewer").hide();
+            }
         },
         invalidToken: function () {
             showPageLogin();
@@ -96,12 +125,14 @@ function viewLog(logFile) {
 
     txtLogViewerTitle.text(logFile);
 
+    var node = $("#optLogsClusterNode").val();
+
     preLogViewerBody.hide();
     divLogViewerLoader.show();
     divLogViewer.show();
 
     HTTPRequest({
-        url: "api/logs/download?token=" + sessionData.token + "&fileName=" + encodeURIComponent(logFile) + "&limit=2",
+        url: "api/logs/download?token=" + sessionData.token + "&fileName=" + encodeURIComponent(logFile) + "&limit=2" + "&node=" + encodeURIComponent(node),
         isTextResponse: true,
         success: function (response) {
             divLogViewerLoader.hide();
@@ -115,7 +146,9 @@ function viewLog(logFile) {
 
 function downloadLog() {
     var logFile = $("#txtLogViewerTitle").text();
-    window.open("api/logs/download?token=" + sessionData.token + "&fileName=" + encodeURIComponent(logFile) + "&ts=" + (new Date().getTime()), "_blank");
+    var node = $("#optLogsClusterNode").val();
+
+    window.open("api/logs/download?token=" + sessionData.token + "&fileName=" + encodeURIComponent(logFile) + "&node=" + encodeURIComponent(node) + "&ts=" + (new Date().getTime()), "_blank");
 }
 
 function deleteLog() {
@@ -124,23 +157,26 @@ function deleteLog() {
     if (!confirm("Are you sure you want to permanently delete the log file '" + logFile + "'?"))
         return;
 
-    var btn = $("#btnDeleteLog").button('loading');
+    var node = $("#optLogsClusterNode").val();
+
+    var btn = $("#btnDeleteLog");
+    btn.button("loading");
 
     HTTPRequest({
-        url: "api/logs/delete?token=" + sessionData.token + "&log=" + logFile,
+        url: "api/logs/delete?token=" + sessionData.token + "&log=" + encodeURIComponent(logFile) + "&node=" + encodeURIComponent(node),
         success: function (responseJSON) {
             refreshLogFilesList();
 
             $("#divLogViewer").hide();
-            btn.button('reset');
+            btn.button("reset");
 
             showAlert("success", "Log Deleted!", "Log file was deleted successfully.");
         },
         error: function () {
-            btn.button('reset');
+            btn.button("reset");
         },
         invalidToken: function () {
-            btn.button('reset');
+            btn.button("reset");
             showPageLogin();
         }
     });
@@ -150,8 +186,10 @@ function deleteAllLogs() {
     if (!confirm("Are you sure you want to permanently delete all log files?"))
         return;
 
+    var node = $("#optLogsClusterNode").val();
+
     HTTPRequest({
-        url: "api/logs/deleteAll?token=" + sessionData.token,
+        url: "api/logs/deleteAll?token=" + sessionData.token + "&node=" + encodeURIComponent(node),
         success: function (responseJSON) {
             refreshLogFilesList();
 
@@ -169,8 +207,10 @@ function deleteAllStats() {
     if (!confirm("Are you sure you want to permanently delete all stats files?"))
         return;
 
+    var node = $("#optLogsClusterNode").val();
+
     HTTPRequest({
-        url: "api/dashboard/stats/deleteAll?token=" + sessionData.token,
+        url: "api/dashboard/stats/deleteAll?token=" + sessionData.token + "&node=" + encodeURIComponent(node),
         success: function (responseJSON) {
             showAlert("success", "Stats Deleted!", "All stats files were deleted successfully.");
         },
@@ -198,8 +238,8 @@ function refreshQueryLogsTab(doQueryLogs) {
         loader = divQueryLogsLoader;
     }
     else {
-        optQueryLogsAppName.prop('disabled', true);
-        optQueryLogsClassPath.prop('disabled', true);
+        optQueryLogsAppName.prop("disabled", true);
+        optQueryLogsClassPath.prop("disabled", true);
     }
 
     HTTPRequest({
@@ -248,8 +288,8 @@ function refreshQueryLogsTab(doQueryLogs) {
                 loader.hide();
             }
             else {
-                optQueryLogsAppName.prop('disabled', false);
-                optQueryLogsClassPath.prop('disabled', false);
+                optQueryLogsAppName.prop("disabled", false);
+                optQueryLogsClassPath.prop("disabled", false);
             }
 
             appsList = apps;
@@ -262,8 +302,8 @@ function refreshQueryLogsTab(doQueryLogs) {
                 frmQueryLogs.show();
             }
             else {
-                optQueryLogsAppName.prop('disabled', false);
-                optQueryLogsClassPath.prop('disabled', false);
+                optQueryLogsAppName.prop("disabled", false);
+                optQueryLogsClassPath.prop("disabled", false);
             }
         },
         invalidToken: function () {
@@ -280,15 +320,15 @@ function queryLogs(pageNumber) {
 
     var name = $("#optQueryLogsAppName").val();
     if (name == null) {
-        showAlert("warning", "Missing!", "Please install the 'Query Logs (Sqlite)' DNS App or any other DNS app that supports query logging feature.");
-        $("#optQueryLogsAppName").focus();
+        showAlert("warning", "Missing!", "Please install the 'Query Logs (Sqlite)' DNS App or any other DNS app that supports query logging feature from the Apps section.");
+        $("#optQueryLogsAppName").trigger("focus");
         return false;
     }
 
     var classPath = $("#optQueryLogsClassPath").val();
     if (classPath == null) {
         showAlert("warning", "Missing!", "Please select a Class Path to query logs.");
-        $("#optQueryLogsClassPath").focus();
+        $("#optQueryLogsClassPath").trigger("focus");
         return false;
     }
 
@@ -317,15 +357,18 @@ function queryLogs(pageNumber) {
     var qtype = $("#txtQueryLogQType").val();
     var qclass = $("#optQueryLogQClass").val();
 
+    var node = $("#optLogsClusterNode").val();
+
     divQueryLogsTable.hide();
     divQueryLogsLoader.show();
 
-    btn.button('loading');
+    btn.button("loading");
 
     HTTPRequest({
         url: "api/logs/query?token=" + sessionData.token + "&name=" + encodeURIComponent(name) + "&classPath=" + encodeURIComponent(classPath) + "&pageNumber=" + pageNumber + "&entriesPerPage=" + entriesPerPage + "&descendingOrder=" + descendingOrder +
             "&start=" + encodeURIComponent(start) + "&end=" + encodeURIComponent(end) + "&clientIpAddress=" + encodeURIComponent(clientIpAddress) + "&protocol=" + protocol + "&responseType=" + responseType + "&rcode=" + rcode +
-            "&qname=" + encodeURIComponent(qname) + "&qtype=" + qtype + "&qclass=" + qclass,
+            "&qname=" + encodeURIComponent(qname) + "&qtype=" + qtype + "&qclass=" + qclass +
+            "&node=" + encodeURIComponent(node),
         success: function (responseJSON) {
             var tableHtml = "";
 
@@ -461,15 +504,15 @@ function queryLogs(pageNumber) {
             $("#tableQueryLogsFooterStatus").html(statusHtml);
             $("#tableQueryLogsFooterPagination").html(paginationHtml);
 
-            btn.button('reset');
+            btn.button("reset");
             divQueryLogsLoader.hide();
             divQueryLogsTable.show();
         },
         error: function () {
-            btn.button('reset');
+            btn.button("reset");
         },
         invalidToken: function () {
-            btn.button('reset');
+            btn.button("reset");
             showPageLogin();
         },
         objLoaderPlaceholder: divQueryLogsLoader
@@ -506,14 +549,14 @@ function exportQueryLogsCsv() {
     var name = $("#optQueryLogsAppName").val();
     if (name == null) {
         showAlert("warning", "Missing!", "Please install the 'Query Logs (Sqlite)' DNS App or any other DNS app that supports query logging feature.");
-        $("#optQueryLogsAppName").focus();
+        $("#optQueryLogsAppName").trigger("focus");
         return false;
     }
 
     var classPath = $("#optQueryLogsClassPath").val();
     if (classPath == null) {
         showAlert("warning", "Missing!", "Please select a Class Path to query logs.");
-        $("#optQueryLogsClassPath").focus();
+        $("#optQueryLogsClassPath").trigger("focus");
         return false;
     }
 
@@ -533,8 +576,11 @@ function exportQueryLogsCsv() {
     var qtype = $("#txtQueryLogQType").val();
     var qclass = $("#optQueryLogQClass").val();
 
+    var node = $("#optLogsClusterNode").val();
+
     window.open("api/logs/export?token=" + sessionData.token + "&name=" + encodeURIComponent(name) + "&classPath=" + encodeURIComponent(classPath) +
         "&start=" + encodeURIComponent(start) + "&end=" + encodeURIComponent(end) + "&clientIpAddress=" + encodeURIComponent(clientIpAddress) +
-        "&protocol=" + protocol + "&responseType=" + responseType + "&rcode=" + rcode + "&qname=" + encodeURIComponent(qname) + "&qtype=" + qtype + "&qclass=" + qclass
+        "&protocol=" + protocol + "&responseType=" + responseType + "&rcode=" + rcode + "&qname=" + encodeURIComponent(qname) + "&qtype=" + qtype + "&qclass=" + qclass +
+        "&node=" + encodeURIComponent(node)
         , "_blank");
 }
